@@ -6,6 +6,16 @@ OSVER=
 OSTYPE=`getconf LONG_BIT`
 MARIADBCPUARCH=
 DLCMD=
+LSPHPVER=73
+MYIP=
+
+testMyIP()
+{   
+    detectdlcmd
+    $DLCMD $LSWS_HOME/myip http://cyberpanel.sh/?ip
+    MYIP=`cat $LSWS_HOME/myip`
+    rm $LSWS_HOME/myip
+}
 
 inst_admin_php()
 {
@@ -72,17 +82,17 @@ install_lsphp7_centos()
 {
     action=install
     ND=nd
-    LSPHPVER=71
+    
     yum -y $action epel-release
     rpm -Uvh http://rpms.litespeedtech.com/centos/litespeed-repo-1.1-1.el$OSVER.noarch.rpm
-    yum -y $action lsphp$LSPHPVER lsphp$LSPHPVER-common lsphp$LSPHPVER-gd lsphp$LSPHPVER-process lsphp$LSPHPVER-mbstring lsphp$LSPHPVER-mysql$ND lsphp$LSPHPVER-xml lsphp$LSPHPVER-mcrypt lsphp$LSPHPVER-pdo lsphp$LSPHPVER-imap
+    yum -y $action lsphp$LSPHPVER lsphp$LSPHPVER-common lsphp$LSPHPVER-gd lsphp$LSPHPVER-process lsphp$LSPHPVER-mbstring lsphp$LSPHPVER-mysql$ND lsphp$LSPHPVER-xml lsphp$LSPHPVER-mcrypt lsphp$LSPHPVER-pdo lsphp$LSPHPVER-imap lsphp$LSPHPVER-json
     
     if [ ! -f "$LSWS_HOME/lsphp$LSPHPVER/bin/lsphp" ] ; then
         action=reinstall
         
         yum -y remove lsphp$LSPHPVER-mysql$ND
         yum -y install lsphp$LSPHPVER-mysql$ND
-        yum -y $action lsphp$LSPHPVER lsphp$LSPHPVER-common lsphp$LSPHPVER-gd lsphp$LSPHPVER-process lsphp$LSPHPVER-mbstring lsphp$LSPHPVER-xml lsphp$LSPHPVER-mcrypt lsphp$LSPHPVER-pdo lsphp$LSPHPVER-imap
+        yum -y $action lsphp$LSPHPVER lsphp$LSPHPVER-common lsphp$LSPHPVER-gd lsphp$LSPHPVER-process lsphp$LSPHPVER-mbstring lsphp$LSPHPVER-xml lsphp$LSPHPVER-mcrypt lsphp$LSPHPVER-pdo lsphp$LSPHPVER-imap lsphp$LSPHPVER-json
     fi
     
     if [ -f "$LSWS_HOME/lsphp$LSPHPVER/bin/lsphp" ] ; then
@@ -92,8 +102,6 @@ install_lsphp7_centos()
 
 install_lsphp7_debian()
 {
-    LSPHPVER=71
-
     grep -Fq  "http://rpms.litespeedtech.com/debian/" /etc/apt/sources.list.d/lst_debian_repo.list
     if [ $? != 0 ] ; then
         echo "deb http://rpms.litespeedtech.com/debian/ $OSVER main"  > /etc/apt/sources.list.d/lst_debian_repo.list
@@ -103,10 +111,10 @@ install_lsphp7_debian()
     wget -O /etc/apt/trusted.gpg.d/lst_repo.gpg http://rpms.litespeedtech.com/debian/lst_repo.gpg
     apt-get -y update
     
-    apt-get -y install lsphp$LSPHPVER lsphp$LSPHPVER-mysql lsphp$LSPHPVER-imap lsphp$LSPHPVER-common 
+    apt-get -y install lsphp$LSPHPVER lsphp$LSPHPVER-mysql lsphp$LSPHPVER-imap lsphp$LSPHPVER-common lsphp$LSPHPVER-curl lsphp$LSPHPVER-json
     
     if [ ! -f "$LSWS_HOME/lsphp$LSPHPVER/bin/lsphp" ] ; then
-        apt-get -y --reinstall install lsphp$LSPHPVER lsphp$LSPHPVER-mysql lsphp$LSPHPVER-imap lsphp$LSPHPVER-common 
+        apt-get -y --reinstall install lsphp$LSPHPVER lsphp$LSPHPVER-mysql lsphp$LSPHPVER-imap lsphp$LSPHPVER-common lsphp$LSPHPVER-curl lsphp$LSPHPVER-json
     fi
     
     if [ -f "$LSWS_HOME/lsphp$LSPHPVER/bin/lsphp" ] ; then
@@ -288,7 +296,7 @@ IS_LSCPD=$9
 VERSION=open
 SETUP_PHP=1
 PHP_SUFFIX="php"
-SSL_HOSTNAME=""
+SSL_HOSTNAME=webadmin
 
 DEFAULT_USER="nobody"
 DEFAULT_GROUP="nobody"
@@ -396,7 +404,8 @@ echo
 
 if [ "x$ADMIN_SSL" = "xyes" ] ; then
     echo "Admin SSL enabled!"
-    gen_selfsigned_cert ./adminssl.conf
+    testMyIP
+    gen_selfsigned_cert_new 
     cp $LSINSTALL_DIR/${SSL_HOSTNAME}.crt $LSINSTALL_DIR/admin/conf/${SSL_HOSTNAME}.crt
     cp $LSINSTALL_DIR/${SSL_HOSTNAME}.key $LSINSTALL_DIR/admin/conf/${SSL_HOSTNAME}.key
 else
