@@ -36,6 +36,7 @@ $_gmsg['menu_vh'] = 'Virtual Hosts';
 $_gmsg['menu_vh_'] = 'Virtual Host';
 $_gmsg['menu_webadmin'] = 'WebAdmin Settings';
 $_gmsg['menu_devgroup'] = 'Developer Mailing List';
+$_gmsg['menu_releaselog'] = 'Release Log';
 $_gmsg['menu_forum'] = 'Forum';
 $_gmsg['menu_slack'] = 'Slack';
 $_gmsg['menu_cloudimage'] = 'Cloud Images';
@@ -84,6 +85,7 @@ $_gmsg['note_confirm_delete'] = 'Are you sure you want to delete this entry? Thi
 $_gmsg['note_confirm_instantiate'] = 'Are you sure you want to instantiate this virtual host? This will create a dedicated configuration file for this virtual host.';
 $_gmsg['note_copyrightreserved'] = 'All Rights Reserved.';
 $_gmsg['note_curver'] = 'Current Version';
+$_gmsg['note_curbranch'] = 'current branch';
 $_gmsg['note_dataretrievedat'] = 'Data retrieved at';
 $_gmsg['note_entfeature'] = 'This feature is available in Enterprise Edition';
 $_gmsg['note_example'] = 'Example';
